<TS version="2.1" language="am">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">አድራሻ ወይም መለያ ስም ለማርተዕ ቀኙን ጠቅ ያድርጉ</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">አዲስ አድራሻ ይፍጠሩ</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;አዲስ</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation type="unfinished">አሁን የተመረጠውን አድራሻ ወደ ስርዓቱ ቅንጥብ ሰሌዳ ቅዳ</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp;ቅዳ</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">ዝጋ</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">አሁን የተመረጠውን አድራሻ ከዝርዝሩ ውስጥ አጥፋ</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">ለመፈለግ አድራሻ ወይም መለያ ያስገቡ</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">በዚህ ማውጫ ውስጥ ያለውን ውሂብ ወደ አንድ ፋይል ቀይረህ አስቀምጥ</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;ላክ</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">&amp;ሰርዝ</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">ገንዘብ/ኮይኖች የሚልኩበትን አድራሻ ይምረጡ</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">ገንዘብ/ኮይኖች የሚቀበሉበትን አድራሻ ይምረጡ</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">ምረጥ</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">ክፍያዎችን ለመላክ እነዚህ  የእርስዎ ቢትኮይን አድራሻዎች ናቸው። ሳንቲሞችን/ኮይኖች ከመላክዎ በፊት ሁል ጊዜ መጠኑን እና የተቀባዩን አድራሻ ያረጋግጡ።</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. Use the 'Create new receiving address' button in the receive tab to create new addresses.
Signing is only possible with addresses of the type 'legacy'.</source>
        <translation type="unfinished">እነኚህ የቢትኮይን አድራሻዎች የክፍያ መቀበያ አድራሻዎችዎ ናችው። "ተቀበል" በሚለው መደብ ውስጥ ያለውን "አዲስ የመቀበያ አድራሻ ይፍጠሩ" የሚለውን አዝራር ይጠቀሙ።
መፈረም የሚቻለው "ሌጋሲ" በሚል ምድብ ስር በተመደቡ አድራሻዎች ብቻ ነው።</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">&amp;አድራሻ ቅዳ</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">ቅዳ &amp;መለያ ስም</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished"> &amp;አርም</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">የአድራሻ ዝርዝር ላክ</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">በንዑስ ሰረዝ የተለዩ ፋይሎች</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <extracomment>An error message. %1 is a stand-in argument for the name of the file we attempted to save to.</extracomment>
        <translation type="unfinished">የአድራሻ ዝርዝሩን ወደ %1 ለማስቀመጥ ሲሞከር ስህተት አጋጥሟል:: እባክዎ መልሰው ይሞክሩ::</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">ወደ ውጪ መላክ አልተሳካም</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">መለያ ስም</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">አድራሻ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(መለያ ስም የለም)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation type="unfinished">የይለፍ-ሐረግ ንግግር</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation type="unfinished">የይለፍ-ሐረግዎን ያስገቡ</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation type="unfinished">አዲስ የይለፍ-ሐረግ</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation type="unfinished">አዲስ የይለፍ-ሐረጉን ይድገሙት</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation type="unfinished">የይለፍ-ሀረጉን አሳይ</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation type="unfinished">የቢትኮይን ቦርሳውን አመስጥር</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation type="unfinished">ይህ ክንዋኔ የቢትኮይን ቦርሳዎን ለመክፈት የቦርሳዎ ይለፍ-ሐረግ ያስፈልገዋል::</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation type="unfinished">የቢትኮይን ቦርሳውን ክፈት</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation type="unfinished">ይለፍ-ሐረግ ለውጥ</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation type="unfinished">የቢትኮይን ቦርሳዎን ማመስጠር ያረጋግጡ</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation type="unfinished">ማስጠንቀቂያ: የቢትኮይን ቦርሳዎን አመስጥረው የይለፍ-ሐረግዎን ካጡት&lt;b&gt;ቢትኮይኖቾን በሙሉ ያጣሉ&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation type="unfinished">እርግጠኛ ነዎት ቦርሳዎን ማመስጠር ይፈልጋሉ?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation type="unfinished">ቦርሳዎ ምስጢር ተደርጓል</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation type="unfinished">ለመመስጠር የተዘጋጀ ዋሌት</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation type="unfinished">ቦርሳዎ ሊመሰጠር ነው። </translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation type="unfinished">ቦርሳዎ አሁን ተመስጥሯል። </translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation type="unfinished">አስፈላጊ: ከ ቦርሳ ፋይልዎ ያከናወኗቸው ቀደም ያሉ ምትኬዎች በአዲስ በተፈጠረ የማመስጠሪያ ፋይል ውስጥ መተካት አለባቸው. ለደህንነት ሲባል, አዲሱን የተመሰጠ የቦርሳ ፋይል መጠቀም ሲጀመሩ ወዲያውኑ ቀደም ሲል ያልተመሰጠሩ የቦርሳ ፋይል ቅጂዎች ዋጋ ቢስ ይሆናሉ::</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation type="unfinished">የቦርሳ ማመስጠር አልተሳካም</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation type="unfinished">የቦርሳ ማመስጠር በውስጣዊ ስህተት ምክንያት አልተሳካም:: ቦርሳዎ አልተመሰጠረም::</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation type="unfinished">የተሰጡት የይለፍ-ሐረግዎች አይዛመዱም::</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation type="unfinished">ቦርሳ መክፈት አልተሳካም</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation type="unfinished">ቦርሳ ለመፍታት ያስገቡት የይለፍ-ሐረግ ትክክል አልነበረም::</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation type="unfinished">የቦርሳ የይለፍ-ሐረግ በተሳካ ሁኔታ ተቀይሯል.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation type="unfinished">ማስጠንቀቂያ: የ "Caps Lock" ቁልፍ በርቷል!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation type="unfinished">አይፒ/ኔትማስክ  IP/Netmask</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation type="unfinished">ታግደዋል እስከ</translation>
    </message>
</context>
<context>
    <name>BitcoinApplication</name>
    <message>
        <source>Internal error</source>
        <translation type="unfinished">ውስጣዊ ስህተት</translation>
    </message>
    <message>
        <source>An internal error occurred. %1 will attempt to continue safely. This is an unexpected bug which can be reported as described below.</source>
        <translation type="unfinished">ውስጣዊ ችግር ተፈጥሯል።  %1 ደህንነቱን ጠብቆ ለመቀጠል ይሞክራል። ይህ ችግር ያልተጠበቀ ሲሆን ከታች በተገለፀው መሰረት ችግሩን ማመልከት ይቻላል። </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Do you want to reset settings to default values, or to abort without making changes?</source>
        <extracomment>Explanatory text shown on startup when the settings file cannot be read. Prompts user to make a choice between resetting or aborting.</extracomment>
        <translation type="unfinished">ቅንብሩን መጀመሪያ ወደነበረው ነባሪ ዋጋ መመለስ ይፈልጋሉ? ወይስ ምንም አይነት ለውጥ ሳያደርጉ እንዲከሽፍ ይፈልጋሉ?</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">ስህተት፥ %1</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">መጠን</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform>%n second(s)</numerusform>
            <numerusform>%n second(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform>%n minute(s)</numerusform>
            <numerusform>%n minute(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform>%n hour(s)</numerusform>
            <numerusform>%n hour(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform>%n day(s)</numerusform>
            <numerusform>%n day(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform>%n week(s)</numerusform>
            <numerusform>%n week(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform>%n year(s)</numerusform>
            <numerusform>%n year(s)</numerusform>
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Overview</source>
        <translation type="unfinished">&amp;አጠቃላይ እይታ</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation type="unfinished">የቦርሳ አጠቃላይ እይታ ኣሳይ</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation type="unfinished">&amp;ግብይቶች</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation type="unfinished">የግብይት ታሪክ ያስሱ</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished">ውጣ</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation type="unfinished">አፕሊኬሽኑን አቁም</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation type="unfinished">&amp;ስለ %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation type="unfinished">ስለ %1 መረጃ አሳይ</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="unfinished">ስለ &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation type="unfinished">ስለ Qt መረጃ አሳይ</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">አዲስ ዋሌት ፍጠር</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">ዋሌት</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="unfinished">&amp;ላክ</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation type="unfinished">&amp;ተቀበል</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;ፋይል</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="unfinished">&amp;ቅንብሮች</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;እርዳታ</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform>Processed %n block(s) of transaction history.</numerusform>
            <numerusform>Processed %n block(s) of transaction history.</numerusform>
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">ስህተት</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">ማሳስቢያ</translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished">መረጃ</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation type="unfinished">ዋሌት ክፈት</translation>
    </message>
    <message>
        <source>Open a wallet</source>
        <translation type="unfinished">ዋሌት ክፈት</translation>
    </message>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">ዋሌት ዝጋ</translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">መደበኛ ዋሌት</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <extracomment>Label of the input field where the name of the wallet is entered.</extracomment>
        <translation type="unfinished">ዋሌት ስም</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation type="unfinished">እሳድግ</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform>%n active connection(s) to Bitcoin network.</numerusform>
            <numerusform>%n active connection(s) to Bitcoin network.</numerusform>
        </translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">ስህተት፥ %1</translation>
    </message>
    <message>
        <source>Warning: %1</source>
        <translation type="unfinished">ማሳሰቢያ፥ %1</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation type="unfinished">ቀን፥ %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation type="unfinished">መጠን፥ %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation type="unfinished">አድራሻ፥ %1
</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation type="unfinished">ብዛት፥</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">መጠን፥</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">ክፍያ፥</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">መጠን</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">ቀን</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">መጠኑ ገልብጥ</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation type="unfinished">ክፍያው ቅዳ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(መለያ ስም የለም)</translation>
    </message>
    </context>
<context>
    <name>OpenWalletActivity</name>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">መደበኛ ዋሌት</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
        <translation type="unfinished">ዋሌት ክፈት</translation>
    </message>
    </context>
<context>
    <name>WalletController</name>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">ዋሌት ዝጋ</translation>
    </message>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Wallet Name</source>
        <translation type="unfinished">ዋሌት ስም</translation>
    </message>
    <message>
        <source>Create</source>
        <translation type="unfinished">ፍጠር</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>name</source>
        <translation type="unfinished">ስም</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Bitcoin</source>
        <translation type="unfinished">ቢትኮይን</translation>
    </message>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform>%n GB of space available</numerusform>
            <numerusform>%n GB of space available</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform>(of %n GB needed)</numerusform>
            <numerusform>(of %n GB needed)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform>(%n GB needed for full chain)</numerusform>
            <numerusform>(%n GB needed for full chain)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform>(sufficient to restore backups %n day(s) old)</numerusform>
            <numerusform>(sufficient to restore backups %n day(s) old)</numerusform>
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">ስህተት</translation>
    </message>
    <message>
        <source>Welcome</source>
        <translation type="unfinished">እንኳን ደህና መጣህ</translation>
    </message>
    <message>
        <source>Welcome to %1.</source>
        <translation type="unfinished">እንኳን  ወድ %1 በደህና መጣህ።</translation>
    </message>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation type="unfinished">ስሪት</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation type="unfinished">ስለ እኛ %1</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation type="unfinished">ከ</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation type="unfinished">ደብቅ</translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Error</source>
        <translation type="unfinished">ስህተት</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation type="unfinished">ከ</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">አድራሻ</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">መጠን፥</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">ዋሌት</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">ቀን</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">መለያ ስም</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(መለያ ስም የለም)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Quantity:</source>
        <translation type="unfinished">ብዛት፥</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">መጠን፥</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">ክፍያ፥</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation type="unfinished">ደብቅ</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">መጠኑ ገልብጥ</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation type="unfinished">ክፍያው ቅዳ</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform>Estimated to begin confirmation within %n block(s).</numerusform>
            <numerusform>Estimated to begin confirmation within %n block(s).</numerusform>
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(መለያ ስም የለም)</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">ቀን</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform>matures in %n more block(s)</numerusform>
            <numerusform>matures in %n more block(s)</numerusform>
        </translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">መጠን</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">ቀን</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">መለያ ስም</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(መለያ ስም የለም)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">በንዑስ ሰረዝ የተለዩ ፋይሎች</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">ቀን</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">መለያ ስም</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">አድራሻ</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">ወደ ውጪ መላክ አልተሳካም</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">አዲስ ዋሌት ፍጠር</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">ስህተት</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">መደበኛ ዋሌት</translation>
    </message>
</context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;ላክ</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">በዚህ ማውጫ ውስጥ ያለውን ውሂብ ወደ አንድ ፋይል ቀይረህ አስቀምጥ</translation>
    </message>
    </context>
</TS>